@@ -29,10 +29,14 @@ from gtk import gdk, keysyms
 from kiwi.component import implements
 from kiwi.interfaces import IEasyCombo
 from kiwi.enums import ComboColumn, ComboMode
+from kiwi.log import Logger
 from kiwi.ui.entry import KiwiEntry
 from kiwi.ui.entrycompletion import KiwiEntryCompletion
 from kiwi.utils import gsignal, type_register
 
+log = Logger('kiwi.ui.combo')
+
+
 class _ComboEntryPopup(gtk.Window):
     gsignal('text-selected', str)
     def __init__(self, comboentry):
@@ -312,21 +316,34 @@ class _ComboEntryPopup(gtk.Window):
     def get_selected_iter(self):
         model, treeiter = self._selection.get_selected()
 
-        # if the model currently being used is a TreeModelFiter, convert
+        # if the model currently being used is a TreeModelFilter, convert
         # the iter to be a TreeModel iter (witch is what the user expects)
         if isinstance(model, gtk.TreeModelFilter) and treeiter:
             treeiter = model.convert_iter_to_child_iter(treeiter)
         return treeiter
 
-    def set_selected_iter(self, iter):
+    def set_selected_iter(self, treeiter):
+        """
+        Selects an item in the comboentry given a treeiter
+        @param treeiter: the tree iter to select
+        """
         model = self._treeview.get_model()
 
         # Since the user passed a TreeModel iter, if the model currently
-        # being used is a TreeModelFiter, convert it to be a TreeModelFiter
+        # being used is a TreeModelFilter, convert it to be a TreeModelFilter
         # iter
         if isinstance(model, gtk.TreeModelFilter):
-            iter = model.convert_child_iter_to_iter(iter)
-        self._selection.select_iter(iter)
+            # See #3099 for an explanation why this is needed and a
+            # testcase
+            tmodel = model.get_model()
+            if tmodel.iter_is_valid(treeiter):
+               # revert back to the unfiltered model so we can select
+               # the right object
+               self._treeview.set_model(tmodel)
+               self._selection = self._treeview.get_selection()
+            else:
+                treeiter = model.convert_child_iter_to_iter(treeiter)
+        self._selection.select_iter(treeiter)
 
 type_register(_ComboEntryPopup)
 
@@ -521,7 +538,9 @@ class ComboEntry(gtk.HBox):
         @type iter: gtk.TreeIter
         """
         self._popup.set_selected_iter(iter)
-        self.set_text(self._model[iter][0])
+        text = self._model[iter][0]
+        if text is not None:
+            self.set_text(text)
 
     def get_active_iter(self):
         """
@@ -537,6 +556,9 @@ class ComboEntry(gtk.HBox):
     def set_label_text(self, text):
         self._popup.set_label_text(text)
 
+    def set_active(self, rowno):
+        self.set_active_iter(self._model[rowno].iter)
+
     # IEasyCombo interface
 
     def clear(self):
@@ -601,7 +623,12 @@ class ComboEntry(gtk.HBox):
         """
         See L{kiwi.interfaces.IEasyCombo.select}
         """
-        treeiter = self.entry.get_iter_from_obj(obj)
+        try:
+            treeiter = self.entry.get_iter_from_obj(obj)
+        except KeyError:
+            log.warn("%s does not contain a %r object" % (
+                self.__class__.__name__, obj))
+            return
         self.set_active_iter(treeiter)
 
     def append_item(self, label, data=None):
