@@ -1,7 +1,7 @@
 #
 # Kiwi: a Framework and Enhanced Widgets for Python
 #
-# Copyright (C) 2006 Async Open Source
+# Copyright (C) 2006-2007 Async Open Source
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -18,9 +18,8 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 # USA
 #
-# Author(s): Christian Reis <kiko@async.com.br>
-#            Lorenzo Gil Sanchez <lgs@sicem.biz>
-#            Gustavo Rahal <gustavo@async.com.br>
+# Author(s): Johan Dahlin <jdahlin@async.com.br>
+#            Ronaldo Maia <romaia@async.com.br>
 #
 
 """GtkEntry support for the Kiwi Framework"""
@@ -65,7 +64,10 @@ class ProxyEntry(KiwiEntry, ValidatableProxyWidgetMixin):
         self._block_changed = False
         KiwiEntry.__init__(self)
         ValidatableProxyWidgetMixin.__init__(self)
-        self.set_property('data-type', data_type)
+        self._data_type = data_type
+
+    def __post_init__(self):
+        self.set_property('data_type', self._data_type)
 
     # Virtual methods
     gsignal('changed', 'override')
@@ -157,7 +159,7 @@ class ProxyEntry(KiwiEntry, ValidatableProxyWidgetMixin):
             # Do not consider masks which only displays static
             # characters invalid, instead return None
             if self.is_empty():
-                return ''
+                return ValueUnset
             text = self.get_text()
             return self._from_string(text)
         elif mode == ENTRY_MODE_DATA:
@@ -212,7 +214,7 @@ class ProxyDateEntry(PropertyObject, DateEntry, ValidatableProxyWidgetMixin):
         metrics = context.get_metrics(context.get_font_description())
         char_width =  metrics.get_approximate_char_width() / pango.SCALE
         current_width = self.entry.get_width_chars()
-    
+
         # We add 4 pixels to the width, because of the icon borders
         icon_width = VALIDATION_ICON_WIDTH + 4
         self.entry.set_width_chars(current_width
